@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000, 2001, 2002 Marco Pesenti Gritti
+ *  Copyright © 2000, 2001, 2002 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-download.c,v 1.13 2005/04/08 20:03:06 chpe Exp $
+ *  $Id: ephy-download.c,v 1.15 2006/09/13 11:34:12 chpe Exp $
  */
 
 #include "config.h"
@@ -56,7 +56,7 @@ ephy_download_get_type (void)
 
         if (G_UNLIKELY (type == 0))
         {
-                static const GTypeInfo our_info =
+                const GTypeInfo our_info =
                 {
                         sizeof (EphyDownloadClass),
                         NULL, /* base_init */
