@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-event.c,v 1.19 2005/01/06 18:14:41 chpe Exp $
+ *  $Id: ephy-embed-event.c,v 1.23 2006/09/13 11:34:13 chpe Exp $
  */
 
 #include "config.h"
@@ -35,7 +35,7 @@ ephy_embed_event_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyEmbedEventIface),
 			ephy_embed_event_base_init,
@@ -59,13 +59,6 @@ ephy_embed_event_base_init (gpointer g_class)
 	initialised = TRUE;
 }
 
-EphyEmbedEventType
-ephy_embed_event_get_event_type (EphyEmbedEvent *event)
-{
-	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
-	return iface->get_type (event);
-}
-
 EphyEmbedEventContext
 ephy_embed_event_get_context (EphyEmbedEvent *event)
 {
@@ -73,6 +66,13 @@ ephy_embed_event_get_context (EphyEmbedEvent *event)
 	return iface->get_context (event);
 }
 
+guint
+ephy_embed_event_get_button (EphyEmbedEvent *event)
+{
+	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
+	return iface->get_button (event);
+}
+
 guint
 ephy_embed_event_get_modifier (EphyEmbedEvent *event)
 {
@@ -88,13 +88,12 @@ ephy_embed_event_get_coords (EphyEmbedEvent *event,
 	iface->get_coordinates (event, x, y);
 }
 
-void
+const GValue*
 ephy_embed_event_get_property	(EphyEmbedEvent *event,
-				 const char *name,
-				 const GValue **value)
+				 const char *name)
 {
 	EphyEmbedEventIface *iface = EPHY_EMBED_EVENT_GET_IFACE (event);
-	iface->get_property (event, name, value);
+	return iface->get_property (event, name);
 }
 
 gboolean
