@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2000-2003 Marco Pesenti Gritti
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2000-2003 Marco Pesenti Gritti
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-embed-event.h,v 1.16 2005/01/23 15:38:02 chpe Exp $
+ *  $Id: ephy-embed-event.h,v 1.19 2006/09/13 11:34:13 chpe Exp $
  */
 
 #ifndef EPHY_EMBED_EVENT_H
@@ -39,14 +39,15 @@ typedef struct _EphyEmbedEvent		EphyEmbedEvent;
 
 typedef enum
 {
-	EPHY_EMBED_CONTEXT_NONE     = 0,
-        EPHY_EMBED_CONTEXT_DEFAULT  = 1 << 1,
-        EPHY_EMBED_CONTEXT_LINK     = 1 << 2,
-        EPHY_EMBED_CONTEXT_IMAGE    = 1 << 3,
-        EPHY_EMBED_CONTEXT_DOCUMENT = 1 << 4,
-        EPHY_EMBED_CONTEXT_INPUT    = 1 << 5,
-        EPHY_EMBED_CONTEXT_XUL      = 1 << 7,
-	EPHY_EMBED_CONTEXT_EMAIL_LINK = 1 << 8
+	EPHY_EMBED_CONTEXT_NONE			= 0,
+        EPHY_EMBED_CONTEXT_DEFAULT		= 1 << 1,
+        EPHY_EMBED_CONTEXT_LINK			= 1 << 2,
+        EPHY_EMBED_CONTEXT_IMAGE		= 1 << 3,
+        EPHY_EMBED_CONTEXT_DOCUMENT		= 1 << 4,
+        EPHY_EMBED_CONTEXT_INPUT		= 1 << 5,
+	EPHY_EMBED_CONTEXT_INPUT_PASSWORD	= 1 << 6,
+        EPHY_EMBED_CONTEXT_XUL			= 1 << 7,
+	EPHY_EMBED_CONTEXT_EMAIL_LINK		= 1 << 8
 } EphyEmbedEventContext;
 
 struct _EphyEmbedEventIface
@@ -60,9 +61,8 @@ struct _EphyEmbedEventIface
 	void			(* get_coordinates)	(EphyEmbedEvent *event,
 							 guint *x,
 							 guint *y);
-	void			(* get_property)	(EphyEmbedEvent *event,
-							 const char *name,
-							 const GValue **value);
+	const GValue*		(* get_property)	(EphyEmbedEvent *event,
+							 const char *name);
 	gboolean		(* has_property)	(EphyEmbedEvent *event,
 							 const char *name);
 	gpointer		(* get_dom_event)	(EphyEmbedEvent *event);
@@ -84,10 +84,8 @@ guint			ephy_embed_event_get_modifier	(EphyEmbedEvent *event);
 void			ephy_embed_event_get_coords	(EphyEmbedEvent *event,
 							 guint *x, guint *y);
 
-
-void			ephy_embed_event_get_property	(EphyEmbedEvent *event,
-							 const char *name,
-							 const GValue **value);
+const GValue*		ephy_embed_event_get_property	(EphyEmbedEvent *event,
+							 const char *name);
 
 gboolean		ephy_embed_event_has_property	(EphyEmbedEvent *event,
 							 const char *name);
