@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Christian Persch
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-permission-manager.h,v 1.4 2003/12/12 21:44:34 chpe Exp $
+ *  $Id: ephy-permission-manager.h,v 1.13 2006/09/13 11:34:13 chpe Exp $
  */
 
 #ifndef EPHY_PERMISSION_MANAGER_H
@@ -29,22 +29,16 @@ G_BEGIN_DECLS
 
 #define EPHY_TYPE_PERMISSION_MANAGER		(ephy_permission_manager_get_type ())
 #define EPHY_PERMISSION_MANAGER(o)		(G_TYPE_CHECK_INSTANCE_CAST ((o), EPHY_TYPE_PERMISSION_MANAGER, EphyPermissionManager))
-#define EPHY_PERMISSION_MANAGER_CLASS(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_PERMISSION_MANAGER, EphyPermissionManagerClass))
+#define EPHY_PERMISSION_MANAGER_IFACE(k)	(G_TYPE_CHECK_CLASS_CAST((k), EPHY_TYPE_PERMISSION_MANAGER, EphyPermissionManagerIface))
 #define EPHY_IS_PERMISSION_MANAGER(o)		(G_TYPE_CHECK_INSTANCE_TYPE ((o), EPHY_TYPE_PERMISSION_MANAGER))
-#define EPHY_IS_PERMISSION_MANAGER_CLASS(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_PERMISSION_MANAGER))
-#define EPHY_PERMISSION_MANAGER_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_PERMISSION_MANAGER, EphyPermissionManagerIFace))
+#define EPHY_IS_PERMISSION_MANAGER_IFACE(k)	(G_TYPE_CHECK_CLASS_TYPE ((k), EPHY_TYPE_PERMISSION_MANAGER))
+#define EPHY_PERMISSION_MANAGER_GET_IFACE(inst)	(G_TYPE_INSTANCE_GET_INTERFACE ((inst), EPHY_TYPE_PERMISSION_MANAGER, EphyPermissionManagerIface))
 
 #define EPHY_TYPE_PERMISSION_INFO		(ephy_permission_info_get_type ())
 
-typedef struct EphyPermissionManager		EphyPermissionManager;
-typedef struct EphyPermissionManagerIFace	EphyPermissionManagerIFace;
-
-typedef enum
-{
-	EPT_COOKIE,
-	EPT_IMAGE,
-	EPT_POPUP
-} EphyPermissionType;
+#define EPT_COOKIE	"cookie"
+#define EPT_IMAGE	"image"
+#define EPT_POPUP	"popup"
 
 typedef enum
 {
@@ -53,14 +47,19 @@ typedef enum
 	EPHY_PERMISSION_DEFAULT
 } EphyPermission;
 
-typedef struct
+typedef struct _EphyPermissionInfo		EphyPermissionInfo;
+
+typedef struct _EphyPermissionManager		EphyPermissionManager;
+typedef struct _EphyPermissionManagerIface	EphyPermissionManagerIface;
+
+struct _EphyPermissionInfo
 {
 	char *host;
-	EphyPermissionType type;
+	GQuark qtype;
 	EphyPermission permission;
-} EphyPermissionInfo;
+};
 
-struct EphyPermissionManagerIFace
+struct _EphyPermissionManagerIface
 {
 	GTypeInterface base_iface;
 
@@ -76,25 +75,27 @@ struct EphyPermissionManagerIFace
 	/* Methods */
 	void		(* add)		(EphyPermissionManager *manager,
 					 const char *host,
-					 EphyPermissionType type,
+					 const char *type,
 					 EphyPermission permission);
 	void		(* remove)	(EphyPermissionManager *manager,
 					 const char *host,
-					 EphyPermissionType type);
+					 const char *type);
 	void		(* clear)	(EphyPermissionManager *manager);
 	EphyPermission	(* test)	(EphyPermissionManager *manager,
 					 const char *host,
-					 EphyPermissionType type);
+					 const char *type);
 	GList *		(* list)	(EphyPermissionManager *manager,
-					 EphyPermissionType type);
+					 const char *type);
 };
 
 /* EphyPermissionInfo */
 
+GType			ephy_permission_get_type	(void);
+
 GType			ephy_permission_info_get_type	(void);
 
 EphyPermissionInfo     *ephy_permission_info_new	(const char *host,
-							 EphyPermissionType type,
+							 const char *type,
 							 EphyPermission permission);
 
 EphyPermissionInfo     *ephy_permission_info_copy	(const EphyPermissionInfo *info);
@@ -105,23 +106,23 @@ void			ephy_permission_info_free	(EphyPermissionInfo *info);
 
 GType 		ephy_permission_manager_get_type	(void);
 
-void		ephy_permission_manager_add		(EphyPermissionManager *manager,
-							 const char *host,
-							 EphyPermissionType type,
-							 EphyPermission permission);
+void		ephy_permission_manager_add_permission		(EphyPermissionManager *manager,
+								 const char *host,
+								 const char *type,
+								 EphyPermission permission);
 
-void		ephy_permission_manager_remove		(EphyPermissionManager *manager,
-							 const char *host,
-							 EphyPermissionType type);
+void		ephy_permission_manager_remove_permission	(EphyPermissionManager *manager,
+								 const char *host,
+								 const char *type);
 
-void		ephy_permission_manager_clear		(EphyPermissionManager *manager);
+void		ephy_permission_manager_clear_permissions	(EphyPermissionManager *manager);
 
-EphyPermission	ephy_permission_manager_test		(EphyPermissionManager *manager,
-							 const char *host,
-							 EphyPermissionType type);
+EphyPermission	ephy_permission_manager_test_permission		(EphyPermissionManager *manager,
+								 const char *host,
+								 const char *type);
 
-GList *		ephy_permission_manager_list		(EphyPermissionManager *manager,
-							 EphyPermissionType type);
+GList *		ephy_permission_manager_list_permissions	(EphyPermissionManager *manager,
+								 const char *type);
 
 G_END_DECLS
 
