@@ -1,8 +1,8 @@
 /*
- *  Copyright (C) 2001 Philip Langdale
- *  Copyright (C) 2003 Marco Pesenti Gritti
- *  Copyright (C) 2003 Xan Lopez
- *  Copyright (C) 2004 Christian Persch
+ *  Copyright © 2001 Philip Langdale
+ *  Copyright © 2003 Marco Pesenti Gritti
+ *  Copyright © 2003 Xan Lopez
+ *  Copyright © 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -18,7 +18,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ContentHandler.cpp,v 1.94 2006/07/06 13:22:34 chpe Exp $
+ *  $Id: ContentHandler.cpp,v 1.97 2006/12/15 14:01:55 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -327,7 +327,7 @@ NS_METHOD GContentHandler::MIMEConfirmAction ()
 	gtk_dialog_add_button (GTK_DIALOG (dialog),
 			       action_label, mAction);
 
-	gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+	gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
  
 	int defaultResponse = mAction == CONTENT_ACTION_NONE
 				? (int) GTK_RESPONSE_CANCEL
@@ -406,6 +406,8 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 	mLauncher->GetMIMEInfo(getter_AddRefs(mimeInfo));
 	NS_ENSURE_TRUE (mimeInfo, NS_ERROR_FAILURE);
 
+	char *info = NULL;
+
 	if (mAction == CONTENT_ACTION_OPEN)
 	{
 		g_return_val_if_fail (mHelperApp, NS_ERROR_FAILURE);
@@ -416,9 +418,15 @@ NS_METHOD GContentHandler::MIMEDoAction (void)
 		/* The current time is fine here as the user has just clicked
 		 * a button (it is used as the time for the application opening)
 		 */
-		char *info;
 		info = g_strdup_printf ("gnome-default:%d:%s", gtk_get_current_event_time(), id);
+	}
+	else if (mAction == CONTENT_ACTION_DOWNLOAD)
+	{
+		info = g_strdup_printf ("gnome-browse-to-file:%d", gtk_get_current_event_time());
+	}
 
+	if (info != NULL)
+	{
 		nsString desc;
 		NS_CStringToUTF16 (nsCString (info),
 			           NS_CSTRING_ENCODING_UTF8, desc);
