@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: EphyFind.cpp,v 1.11 2006/09/17 18:38:58 chpe Exp $
+ *  $Id: EphyFind.cpp,v 1.12 2006/12/01 21:29:19 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -198,7 +198,8 @@ EphyFind::Find (const char *aSearchString,
 }
 
 EphyEmbedFindResult
-EphyFind::FindAgain (PRBool aForward)
+EphyFind::FindAgain (PRBool aForward,
+		     PRBool aLinksOnly)
 {
   if (!mFinder) return EPHY_EMBED_FIND_NOTFOUND;
 
@@ -207,7 +208,7 @@ EphyFind::FindAgain (PRBool aForward)
   nsresult rv;
   PRUint16 found = nsITypeAheadFind::FIND_NOTFOUND;
 #ifdef HAVE_GECKO_1_9
-  rv = mFinder->FindAgain (!aForward, mHasFocus, &found);
+  rv = mFinder->FindAgain (!aForward, aLinksOnly, mHasFocus, &found);
 #else
   if (aForward) {
     rv = mFinder->FindNext (&found);
