@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: GeckoPrintSession.cpp 6845 2007-01-23 17:42:11Z chpe $
+ *  $Id: GeckoPrintSession.cpp,v 1.4 2006/12/04 22:10:37 chpe Exp $
  */
 
 #include "mozilla-config.h"
@@ -105,7 +105,7 @@ GeckoPrintSession::SetSettings (GtkPrintSettings *aSettings,
   NS_ASSERTION (!mSettings && !mPageSetup && !mPrinter, "Already have settings!");
 
   NS_ENSURE_ARG (aSettings);
-  mSettings = (GtkPrintSettings *) g_object_ref (aSettings);
+  mSettings = aSettings; /* this one is adopted */
 
   NS_ENSURE_ARG (aPageSetup);
   NS_ENSURE_ARG (aPrinter);
@@ -130,7 +130,7 @@ GeckoPrintSession::SetSettings (GtkPrintSettings *aSettings,
   {
     char *base, *tmpName;
 
-    /* FIXME: use pure glib here! */
+    /* FIXME: use pure glib here (g_mkstemp)! */
     base = g_build_filename (ephy_file_tmp_dir (), "print-XXXXXX", (const char *) NULL);
     tmpName = ephy_file_tmp_filename (base, "ps");
     g_free (base);
