@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-gui.c,v 1.51 2006/09/13 11:34:19 chpe Exp $
+ *  $Id: ephy-gui.c,v 1.52 2006/12/15 14:01:55 chpe Exp $
  */
 
 #include "config.h"
 
 #include "ephy-gui.h"
 #include "eel-gconf-extensions.h"
+#include "ephy-stock-icons.h"
 #include "ephy-debug.h"
 
 #include <ctype.h>
@@ -297,7 +298,7 @@ ephy_gui_check_location_writable (GtkWidget *parent,
 					  "create files in this directory."));
 
 			gtk_window_set_title (GTK_WINDOW (dialog), _("Directory not Writable"));
-			gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+			gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 			if (parent != NULL)
 			{
@@ -334,7 +335,7 @@ ephy_gui_check_location_writable (GtkWidget *parent,
 				  "you don't have permission to overwrite it."));
 
 		gtk_window_set_title (GTK_WINDOW (dialog), _("Cannot Overwrite File"));
-		gtk_window_set_icon_name (GTK_WINDOW (dialog), "web-browser");
+		gtk_window_set_icon_name (GTK_WINDOW (dialog), EPHY_STOCK_EPHY);
 
 		if (parent != NULL)
 		{
