@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-spell-check.c,v 1.5 2006/11/03 19:13:58 chpe Exp $
+ *  $Id: ephy-spell-check.c,v 1.6 2006/12/15 14:01:55 chpe Exp $
  */
 
 #include "config.h"
@@ -43,7 +43,7 @@ enum
 	LAST_SIGNAL
 };
 
-static guint signals[LAST_SIGNAL];
+/* static guint signals[LAST_SIGNAL]; */
 static GObjectClass *parent_class;
 
 /* Helper functions */
