@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-stock-icons.h,v 1.21 2006/09/13 11:34:19 chpe Exp $
+ *  $Id: ephy-stock-icons.h,v 1.26 2006/12/15 14:01:55 chpe Exp $
  */
 
 #ifndef EPHY_STOCK_ICONS_H
@@ -23,15 +23,17 @@
 
 G_BEGIN_DECLS
 
-#define EPHY_STOCK_POPUPS	   "epiphany-popup-hidden"
-#define EPHY_STOCK_HISTORY         "epiphany-history"
-#define EPHY_STOCK_BOOKMARKS       "epiphany-bookmarks"
-#define EPHY_STOCK_ENTRY	   "epiphany-entry"
-#define EPHY_STOCK_DOWNLOAD	   "epiphany-download"
+#define EPHY_STOCK_EPHY		   "web-browser"
+
+#define EPHY_STOCK_POPUPS	   "popup-hidden"
+#define EPHY_STOCK_HISTORY         "history-view"
+#define EPHY_STOCK_BOOKMARKS       "bookmark-view"
+#define EPHY_STOCK_ENTRY	   "location-entry"
+#define EPHY_STOCK_DOWNLOAD	   "download"
 
 #define STOCK_NEW_TAB              "tab-new"
 #define STOCK_NEW_WINDOW           "window-new"
-#define STOCK_VIEW_SOURCE	   "stock_view-html-source"
+#define STOCK_VIEW_SOURCE	   "text-html"
 #define STOCK_SEND_MAIL            "mail-forward"
 #define STOCK_ADD_BOOKMARK         "bookmark-new"
 #define STOCK_BOOKMARK             "stock_bookmark"
