@@ -1,5 +1,5 @@
 /*  Rhythmbox.
- *  Copyright (C) 2002 Olivier Martin <omartin@ifrance.com>
+ *  Copyright © 2002 Olivier Martin <omartin@ifrance.com>
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-tree-model-sort.c,v 1.15 2005/01/28 22:24:17 chpe Exp $
+ *  $Id: ephy-tree-model-sort.c,v 1.17 2006/09/13 11:34:21 chpe Exp $
  */
 
 #include "config.h"
@@ -61,7 +61,7 @@ ephy_tree_model_sort_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info =
+		const GTypeInfo our_info =
 		{
 			sizeof (EphyTreeModelSortClass),
 			NULL, /* base init */
@@ -73,7 +73,7 @@ ephy_tree_model_sort_get_type (void)
 			0, /* n_preallocs */
 			(GInstanceInitFunc) ephy_tree_model_sort_init
 		};
-		static const GInterfaceInfo multi_drag_source_info =
+		const GInterfaceInfo multi_drag_source_info =
 		{
 			(GInterfaceInitFunc) ephy_tree_model_sort_multi_drag_source_init,
 			NULL,
