@@ -1,7 +1,7 @@
 /*
- *  Copyright (C) 2003, 2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
- *  Copyright (C) 2005 Peter Harvey
+ *  Copyright © 2003, 2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
+ *  Copyright © 2005 Peter Harvey
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-bookmark-action.c,v 1.79 2006/02/24 14:57:04 paharvey Exp $
+ *  $Id: ephy-bookmark-action.c,v 1.82 2006/09/13 11:34:24 chpe Exp $
  */
 
 #include "config.h"
@@ -135,8 +135,8 @@ ephy_bookmark_action_sync_smart_url (GtkAction *gaction,
 		EphyBookmarkAction *action = EPHY_BOOKMARK_ACTION (gaction);
 		EphyBookmarkActionPrivate *priv = action->priv;
 		gboolean is_smart_url = priv->smart_url;
-		gboolean has_icon = (gboolean) ephy_node_get_property_string
-		  (priv->node, EPHY_NODE_BMK_PROP_ICON);		
+		gboolean has_icon = ephy_node_get_property_string
+		  (priv->node, EPHY_NODE_BMK_PROP_ICON) != NULL;
 		GtkWidget *entry, *icon;
 		guint width;
 
@@ -725,7 +725,7 @@ ephy_bookmark_action_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo type_info =
+		const GTypeInfo type_info =
 		{
 			sizeof (EphyBookmarkActionClass),
 			(GBaseInitFunc) NULL,
