@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-location-action.c,v 1.48 2006/10/22 17:08:06 jframeau Exp $
+ *  $Id: ephy-location-action.c,v 1.50 2006/12/18 12:35:02 chpe Exp $
  */
 
 #include "config.h"
@@ -368,7 +368,9 @@ connect_proxy (GtkAction *action, GtkWidget *proxy)
 						    EPHY_COMPLETION_TEXT_COL,
 						    EPHY_COMPLETION_ACTION_COL,
 						    EPHY_COMPLETION_KEYWORDS_COL,
-						    EPHY_COMPLETION_RELEVANCE_COL);
+						    EPHY_COMPLETION_RELEVANCE_COL,
+						    EPHY_COMPLETION_EXTRA_COL,
+						    EPHY_COMPLETION_FAVICON_COL);
 
 		add_completion_actions (action, proxy);
 
