@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-statusbar.h,v 1.11 2006/09/13 11:34:23 chpe Exp $
+ *  $Id: ephy-statusbar.h,v 1.12 2006/12/03 19:05:19 chpe Exp $
  */
 
 #ifndef EPHY_STATUSBAR_H
@@ -45,8 +45,6 @@ struct _EphyStatusbar
 
 	/*< public >*/
 	GtkTooltips *tooltips;
-	GtkWidget *security_frame;
-	GtkWidget *popups_manager_frame;
 
 	/*< private >*/
         EphyStatusbarPrivate *priv;
