@@ -17,7 +17,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbar.c,v 1.34 2006/10/17 20:56:10 chpe Exp $
+ *  $Id: ephy-toolbar.c,v 1.35 2006/12/15 14:01:57 chpe Exp $
  */
 
 #include "config.h"
@@ -560,7 +560,7 @@ ephy_toolbar_constructor (GType type,
 	gtoolbar = GTK_TOOLBAR (priv->fixed_toolbar);
 	gtk_toolbar_set_show_arrow (gtoolbar, FALSE);
 
-	priv->spinner = ephy_spinner_tool_item_new ();
+	priv->spinner = EPHY_SPINNER_TOOL_ITEM (ephy_spinner_tool_item_new ());
 	gtk_toolbar_insert (gtoolbar, GTK_TOOL_ITEM (priv->spinner), -1);
 	gtk_widget_show (GTK_WIDGET (priv->spinner));
 
