@@ -1,6 +1,6 @@
 /*
- *  Copyright (C) 2002-2004 Marco Pesenti Gritti
- *  Copyright (C) 2003, 2004 Christian Persch
+ *  Copyright © 2002-2004 Marco Pesenti Gritti
+ *  Copyright © 2003, 2004 Christian Persch
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -16,7 +16,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: ephy-toolbars-model.c,v 1.39 2006/02/04 10:43:24 paharvey Exp $
+ *  $Id: ephy-toolbars-model.c,v 1.41 2006/09/13 11:34:23 chpe Exp $
  */
 
 #include "config.h"
@@ -55,7 +55,7 @@ ephy_toolbars_model_get_type (void)
 
 	if (G_UNLIKELY (type == 0))
 	{
-		static const GTypeInfo our_info = {
+		const GTypeInfo our_info = {
 		sizeof (EphyToolbarsModelClass),
 		NULL,			/* base_init */
 		NULL,			/* base_finalize */
