@@ -1,5 +1,5 @@
 /*
- *  Copyright (C) 2000-2004 Marco Pesenti Gritti
+ *  Copyright © 2000-2004 Marco Pesenti Gritti
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *  Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
  *
- *  $Id: window-commands.c,v 1.192 2006/03/23 16:43:28 chpe Exp $
+ *  $Id: window-commands.c,v 1.201 2006/12/17 19:04:48 chpe Exp $
  */
 
 #include "config.h"
@@ -46,6 +46,7 @@
 #include "ephy-location-entry.h"
 #include "ephy-bookmarks-ui.h"
 #include "ephy-link.h"
+#include "ephy-stock-icons.h"
 #include "pdm-dialog.h"
 
 #include <string.h>
@@ -59,17 +60,32 @@
 #include <gtk/gtkmain.h>
 #include <gtk/gtkicontheme.h>
 #include <gtk/gtktoggleaction.h>
+#include <gtk/gtkprintoperation.h>
 #include <glib/gi18n.h>
 
+static void
+page_setup_done_cb (GtkPageSetup *setup,
+		    EphyEmbedShell *shell)
+{
+	if (setup != NULL)
+	{
+		ephy_embed_shell_set_page_setup (shell, setup);
+	}
+}
+
 void
 window_cmd_file_print_setup (GtkAction *action,
 			     EphyWindow *window)
 {
-	EphyDialog *dialog;
+	EphyEmbedShell *shell;
 
-	dialog = EPHY_DIALOG (ephy_shell_get_print_setup_dialog (ephy_shell));
-
-	ephy_dialog_show (dialog);
+	shell = ephy_embed_shell_get_default ();
+	gtk_print_run_page_setup_dialog_async
+		(GTK_WINDOW (window),
+		 ephy_embed_shell_get_page_setup (shell),
+		 ephy_embed_shell_get_print_settings (shell),
+		 (GtkPageSetupDoneFunc) page_setup_done_cb,
+		 shell);
 }
 
 void
@@ -187,35 +203,6 @@ window_cmd_view_reload (GtkAction *action,
 	ephy_embed_reload (embed, event_with_shift ());
 }
 
-void
-window_cmd_file_new_window (GtkAction *action,
-		            EphyWindow *window)
-{
-	EphyTab *tab;
-
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
-
-	ephy_shell_new_tab (ephy_shell, window, tab, NULL,
-			    EPHY_NEW_TAB_NEW_PAGE |
-			    EPHY_NEW_TAB_IN_NEW_WINDOW);
-}
-
-void
-window_cmd_file_new_tab (GtkAction *action,
-		         EphyWindow *window)
-{
-	EphyTab *tab;
-
-	tab = ephy_window_get_active_tab (window);
-	g_return_if_fail (tab != NULL);
-
-	ephy_shell_new_tab (ephy_shell, window, tab, NULL,
-			    EPHY_NEW_TAB_NEW_PAGE |
-			    EPHY_NEW_TAB_IN_EXISTING_WINDOW |
-			    EPHY_NEW_TAB_JUMP);
-}
-
 void
 window_cmd_go_bookmarks (GtkAction *action,
 			 EphyWindow *window)
@@ -448,6 +435,28 @@ window_cmd_edit_paste (GtkAction *action,
 	}
 }
 
+void
+window_cmd_edit_delete (GtkAction *action,
+			EphyWindow *window)
+{
+	GtkWidget *widget = gtk_window_get_focus (GTK_WINDOW (window));
+
+	if (GTK_IS_EDITABLE (widget))
+	{
+		gtk_editable_delete_text (GTK_EDITABLE (widget), 0, -1);
+	}
+	else
+	{
+		EphyEmbed *embed;
+
+		embed = ephy_window_get_active_embed (window);
+		g_return_if_fail (embed != NULL);
+
+		ephy_command_manager_do_command (EPHY_COMMAND_MANAGER (embed),
+						 "cmd_delete");
+	}
+}
+
 void
 window_cmd_edit_select_all (GtkAction *action,
 			    EphyWindow *window)
@@ -621,6 +630,18 @@ window_cmd_view_page_source (GtkAction *action,
 	}
 }
 
+void
+window_cmd_view_page_security_info (GtkAction *action,
+				    EphyWindow *window)
+{
+	EphyEmbed *embed;
+
+	embed = ephy_window_get_active_embed (window);
+	g_return_if_fail (EPHY_IS_EMBED (embed));
+
+	ephy_embed_show_page_certificate (embed);
+}
+
 void
 window_cmd_go_history (GtkAction *action,
 		       EphyWindow *window)
@@ -700,40 +721,12 @@ window_cmd_help_contents (GtkAction *action,
 	ephy_gui_help (GTK_WINDOW (window), "epiphany", NULL);
 }
 
+#define ABOUT_GROUP "About"
+
 void
 window_cmd_help_about (GtkAction *action,
 		       GtkWidget *window)
 {
-	const char * const authors[] = {
-		"Marco Pesenti Gritti",
-		"Adam Hooper",
-		"Xan Lopez",
-		"Christian Persch",
-		"Jean-François Rameau",
-		"",
-		_("Contact us at:"),
-		"<epiphany-list@gnome.org>",
-		"",
-		_("Contributors:"),
-		"Crispin Flowerday",
-		"Peter Harvey",
-		"Raphaël Slinckx",
-		"",
-		_("Past developers:"),
-		"David Bordoley",
-		NULL,
-	};
-	const char * const documenters[] = {
-		"Piers Cornwell", 
-		"Victor Osadci",
-		"Patanjali Somayaji",
-		"David Bordoley",
-		"",
-		_("Contact us at:"),
-		_("<epiphany-list@gnome.org> or <gnome-doc-list@gnome.org>"),
-		NULL
-	};
-
 	const char *licence_part[] = {
 		N_("The GNOME Web Browser is free software; you can redistribute it and/or modify "
 		   "it under the terms of the GNU General Public License as published by "
@@ -751,6 +744,81 @@ window_cmd_help_about (GtkAction *action,
 	EphyEmbedShell *shell;
 	EphyEmbedSingle *single;
 	char *licence, *comments;
+	GKeyFile *key_file;
+	GError *error = NULL;
+	char **list, **authors, **contributors, **past_authors, **artists, **documenters;
+	gsize n_authors, n_contributors, n_past_authors, n_artists, n_documenters, i, j;
+
+	key_file = g_key_file_new ();
+	if (!g_key_file_load_from_file (key_file, DATADIR G_DIR_SEPARATOR_S "about.ini",
+				        0, &error))
+	{
+		g_warning ("Couldn't load about data: %s\n", error->message);
+		g_error_free (error);
+		return;
+	}
+
+	list = g_key_file_get_string_list (key_file, ABOUT_GROUP, "Authors",
+					   &n_authors, NULL);
+	contributors = g_key_file_get_string_list (key_file, ABOUT_GROUP, "Contributors",
+						   &n_contributors, NULL);
+	past_authors = g_key_file_get_string_list (key_file, ABOUT_GROUP, "PastAuthors",
+						   &n_past_authors, NULL);
+
+#define APPEND(_to,_from) \
+	_to[i++] = g_strdup (_from);
+
+#define APPEND_STRV_AND_FREE(_to,_from) \
+	if (_from)\
+	{\
+		for (j = 0; _from[j] != NULL; ++j)\
+		{\
+			_to[i++] = _from[j];\
+		}\
+		g_free (_from);\
+	}
+
+	authors = g_new (char *, (list ? n_authors : 0) +
+			 	 (contributors ? n_contributors : 0) +
+				 (past_authors ? n_past_authors : 0) + 7 + 1);
+	i = 0;
+	APPEND_STRV_AND_FREE (authors, list);
+	APPEND (authors, "");
+	APPEND (authors, _("Contact us at:"));
+	APPEND (authors, "<epiphany-list@gnome.org>");
+	APPEND (authors, "");
+	APPEND (authors, _("Contributors:"));
+	APPEND_STRV_AND_FREE (authors, contributors);
+	APPEND (authors, "");
+	APPEND (authors, _("Past developers:"));
+	APPEND_STRV_AND_FREE (authors, past_authors);
+	authors[i++] = NULL;
+
+	list = g_key_file_get_string_list (key_file, ABOUT_GROUP, "Artists", &n_artists, NULL);
+
+	artists = g_new (char *, (list ? n_artists : 0) + 4 + 1);
+	i = 0;
+	APPEND_STRV_AND_FREE (artists, list);
+	APPEND (artists, "");
+	APPEND (artists, _("Contact us at:"));
+	APPEND (artists, "<gnome-art-list@gnome.org>");
+	APPEND (artists, "<gnome-themes-list@gnome.org>");
+	artists[i++] = NULL;
+	
+	list = g_key_file_get_string_list (key_file, ABOUT_GROUP, "Documenters", &n_documenters, NULL);
+
+	documenters = g_new (char *, (list ? n_documenters : 0) + 3 + 1);
+	i = 0;
+	APPEND_STRV_AND_FREE (documenters, list);
+	APPEND (documenters, "");
+	APPEND (documenters, _("Contact us at:"));
+	APPEND (documenters, "<gnome-doc-list@gnome.org>");
+	documenters[i++] = NULL;
+	
+#undef APPEND
+#undef APPEND_STRV_AND_FREE
+
+	g_key_file_free (key_file);
 
 	shell = ephy_embed_shell_get_default ();
 	single = EPHY_EMBED_SINGLE (ephy_embed_shell_get_embed_single (shell));
@@ -769,6 +837,7 @@ window_cmd_help_about (GtkAction *action,
 			       "version", VERSION,
 			       "copyright", "Copyright © 2002-2004 Marco Pesenti Gritti\n"
 					    "Copyright © 2003-2006 The GNOME Web Browser Developers",
+			       "artists", artists,
 			       "authors", authors,
 			       "comments", comments,
 			       "documenters", documenters,
@@ -781,7 +850,7 @@ window_cmd_help_about (GtkAction *action,
 				 * line seperated by newlines (\n).
 				 */
 			       "translator-credits", _("translator-credits"),
-			       "logo-icon-name", "web-browser",
+			       "logo-icon-name", EPHY_STOCK_EPHY,
 			       "website", "http://www.gnome.org/projects/epiphany",
 			       "website-label", _("GNOME Web Browser Website"),
 			       "license", licence,
@@ -790,6 +859,9 @@ window_cmd_help_about (GtkAction *action,
 
 	g_free (comments);
 	g_free (licence);
+	g_strfreev (artists);
+	g_strfreev (authors);
+	g_strfreev (documenters);
 }
 
 void
